@@ -23,6 +23,8 @@
 (declare-function ai-code-cli-switch-to-buffer "ai-code-interface" ())
 (declare-function gptel-request "gptel" (prompt &rest args))
 (declare-function gptel-abort "gptel" (buffer))
+(declare-function ai-code--git-repo-recent-modified-files "ai-code-git" (base-dir limit))
+(declare-function ai-code--git-ignored-repo-file-p "ai-code-git" (file root))
 
 (defcustom ai-code-prompt-preprocess-filepaths t
   "When non-nil, preprocess the prompt to replace file paths.
@@ -203,6 +205,108 @@ NOTE: This does not handle file paths containing spaces."
     ;; Not in a git repo, return original prompt
     prompt-text))
 
+(defun ai-code--file-in-git-repo-p (file git-root-truename)
+  "Return non-nil when FILE is a regular file under GIT-ROOT-TRUENAME."
+  (when (and file (file-exists-p file))
+    (let ((truename (file-truename file)))
+      (and (file-regular-p truename)
+           (string-prefix-p git-root-truename truename)))))
+
+(defun ai-code--relative-filepath (file git-root-truename)
+  "Return FILE relative to GIT-ROOT-TRUENAME, prefixed with '@'."
+  (concat "@" (file-relative-name (file-truename file) git-root-truename)))
+
+(defun ai-code--visible-window-files (git-root-truename)
+  "Return visible window file list under GIT-ROOT-TRUENAME."
+  (let ((files '())
+        (selected (selected-window)))
+    (dolist (win (cons selected
+                       (delq selected (window-list nil 'no-minibuffer))))
+      (let* ((buf (window-buffer win))
+             (file (buffer-file-name buf)))
+        (when (and (ai-code--file-in-git-repo-p file git-root-truename)
+                   (not (ai-code--git-ignored-repo-file-p file git-root-truename)))
+          (push file files))))
+    (nreverse (delete-dups files))))
+
+(defun ai-code--buffer-file-list (git-root-truename &optional skip-files)
+  "Return buffer file list under GIT-ROOT-TRUENAME, skipping SKIP-FILES."
+  (let ((files '()))
+    (dolist (buf (buffer-list))
+      (let ((file (buffer-file-name buf)))
+        (when (and (ai-code--file-in-git-repo-p file git-root-truename)
+                   (not (ai-code--git-ignored-repo-file-p file git-root-truename))
+                   (not (member (file-truename file) skip-files)))
+          (push file files))))
+    (nreverse files)))
+
+(defun ai-code--repo-recent-files (git-root)
+  "Return top 1000 most recently modified files under GIT-ROOT."
+  (ai-code--git-repo-recent-modified-files git-root 1000))
+
+(defun ai-code--dedupe-preserve-order (items)
+  "Return ITEMS with duplicates removed while preserving order."
+  (let ((seen (make-hash-table :test #'equal))
+        (result '()))
+    (dolist (item items)
+      (unless (gethash item seen)
+        (puthash item t seen)
+        (push item result)))
+    (nreverse result)))
+
+(defun ai-code--prompt-filepath-candidates ()
+  "Return file path candidates for prompt completion."
+  (when-let ((git-root (magit-toplevel)))
+    (let* ((git-root-truename (file-truename git-root))
+           (current-file (buffer-file-name (current-buffer)))
+           (visible-files (ai-code--visible-window-files git-root-truename))
+           (skip-files (mapcar #'file-truename visible-files))
+           (buffer-files (ai-code--buffer-file-list git-root-truename skip-files))
+           (recent-files (ai-code--repo-recent-files git-root-truename))
+           (ignore-prefix (concat "@" ai-code-files-dir-name "/"))
+           (visible-paths (mapcar (lambda (file)
+                                    (ai-code--relative-filepath file git-root-truename))
+                                  visible-files))
+           (buffer-paths (mapcar (lambda (file)
+                                   (ai-code--relative-filepath file git-root-truename))
+                                 buffer-files))
+           (recent-paths (mapcar (lambda (file)
+                                   (ai-code--relative-filepath file git-root-truename))
+                                 recent-files))
+           (combined (append visible-paths buffer-paths recent-paths))
+           (deduped (ai-code--dedupe-preserve-order combined))
+           (filtered '()))
+      (dolist (item deduped)
+        (unless (or (string-prefix-p ignore-prefix item)
+                    (and current-file
+                         (string= item (ai-code--relative-filepath current-file git-root-truename))))
+          (push item filtered)))
+      (nreverse filtered))))
+
+(defun ai-code--prompt-filepath-capf ()
+  "Provide completion candidates for @file paths in prompt buffer."
+  (when (and (not (minibufferp)) (magit-toplevel))
+    (let ((end (point))
+          (start (save-excursion
+                   (skip-chars-backward "A-Za-z0-9_./-")
+                   (when (eq (char-before) ?@)
+                     (1- (point))))))
+      (when start
+        (let ((candidates (ai-code--prompt-filepath-candidates)))
+          (when candidates
+            (list start end candidates :exclusive 'no)))))))
+
+(defun ai-code--prompt-auto-trigger-filepath-completion ()
+  "Auto trigger file path completion when '@' is inserted."
+  (when (and (not (minibufferp))
+             (eq (char-before) ?@))
+    (let ((candidates (ai-code--prompt-filepath-candidates)))
+      (when candidates
+        (let ((choice (completing-read "File: " candidates nil nil)))
+          (when (and choice (not (string-empty-p choice)))
+            (delete-char -1)  ; Remove the '@' we just typed
+            (insert choice)))))))
+
 (defun ai-code--insert-prompt (prompt-text)
   "Preprocess and insert PROMPT-TEXT into the AI prompt file.
 If PROMPT-TEXT is a command (starts with /), execute it directly instead."
@@ -225,6 +329,8 @@ Special commands:
   (setq-local comment-end "")
   (setq-local truncate-lines nil)  ; Disable line truncation, allowing lines to wrap
   (define-key ai-code-prompt-mode-map (kbd "C-c C-c") #'ai-code-prompt-send-block)
+  (add-hook 'completion-at-point-functions #'ai-code--prompt-filepath-capf nil t)
+  (add-hook 'post-self-insert-hook #'ai-code--prompt-auto-trigger-filepath-completion nil t)
   ;; YASnippet support
   (when (require 'yasnippet nil t)
     (yas-minor-mode 1)
@@ -343,7 +449,12 @@ using GPTel, and creates the task file."
 
 ;;;###autoload
 (add-to-list 'auto-mode-alist
-             `(,(concat "/" (regexp-quote ai-code-prompt-file-name) "\\'") . ai-code-prompt-mode))
+             `(,(concat "^"
+                        (regexp-quote
+                         (file-name-as-directory
+                          (expand-file-name ai-code-files-dir-name)))
+                        ".*\\.org\\'")
+               . ai-code-prompt-mode))
 
 (provide 'ai-code-prompt-mode)
 
