@@ -1,8 +1,8 @@
 ;;; ai-code.el --- Unified interface for AI coding CLI such as Claude Code, Codex CLI, Gemini CLI, Copilot CLI, Opencode, Grok CLI, etc -*- lexical-binding: t; -*-
 
 ;; Author: Kang Tu <tninja@gmail.com>
-;; Package-Version: 1.22
-;; Package-Revision: 3cd3bf60a9ad
+;; Package-Version: 1.30
+;; Package-Revision: da92457bd6fe
 ;; Package-Requires: ((emacs "28.1") (transient "0.8.0") (magit "2.1.0"))
 ;; URL: https://github.com/tninja/ai-code-interface.el
 
@@ -33,13 +33,16 @@
 ;;   ;; use codex as backend, other options are 'gemini, 'github-copilot-cli, 'opencode, 'grok, 'claude-code-ide, 'claude-code-el, 'claude-code, 'cursor, 'kiro
 ;;   (ai-code-set-backend 'codex) ;; set your preferred backend
 ;;   (global-set-key (kbd "C-c a") #'ai-code-menu)
+;;   ;; Optional: Enable @ file completion in comments and AI sessions
+;;   (ai-code-prompt-filepath-completion-mode 1)
 ;;   (global-auto-revert-mode 1)
-;;   (setq auto-revert-interval 1)) ;; set to 1 second for faster update
+;;   (setq auto-revert-interval 1) ;; set to 1 second for faster update
+;;   )
 ;;
 ;; Key features:
 ;;   - Transient-driven Hub (C-c a) for all AI capabilities.
 ;;   - One key switching to different AI backend (C-c a s).
-;;   - Context-aware code actions (change code, implement TODOs, explain code).
+;;   - Context-aware code actions (change code, implement TODOs, explain code, @ completion).
 ;;   - Agile development workflows (TDD cycle, refactoring navigator, review helper).
 ;;   - Seamless prompt management using Org-mode.
 ;;   - AI-assisted bash commands and productivity utilities.
@@ -242,6 +245,7 @@ Shows the current backend label to the right."
     ("f" "Fix Flycheck errors in scope" ai-code-flycheck-fix-errors-in-scope)
     ("k" "Copy Cur File Name (C-u: full)" ai-code-copy-buffer-file-name-to-clipboard)
     ("d" "Toggle current buffer dedicated" ai-code-toggle-current-buffer-dedicated)
+    ("o" "Open recent file (C-u: insert)" ai-code-git-repo-recent-modified-files)
     ;; ("o" "Open Clipboard file dir" ai-code-open-clipboard-file-path-as-dired)
     ("m" "Debug python MCP server" ai-code-debug-mcp)
     ("n" "Take notes from AI session region" ai-code-take-notes)
